@@ -2,7 +2,7 @@
 
 string Cron::hmac(string const &passPhrase)
 {
-    HMacBuf hmacbuf(passPhrase, "sha256", 1024);
+    HMacBuf hmacbuf(passPhrase, "aes-256-cbc", "sha256", 1024);
 
     ostream out(&hmacbuf);
     out << passPhrase << eoi;
