@@ -11,7 +11,7 @@ namespace   // the anonymous namespace can be used here
         Arg::LongOption("version", 'v'),
 
         Arg::LongOption("list", 'l'),
-        Arg::LongOption("no-daemon", Arg::None),
+        Arg::LongOption("no-daemon", Arg::NoArg),
         Arg::LongOption("reload", 'r'),
         Arg::LongOption("stdout", 's'),
         Arg::LongOption("terminate", 't'),
@@ -27,12 +27,12 @@ namespace   // the anonymous namespace can be used here
         Arg::LongOption("log",  'L'),
         Arg::LongOption("mailer", 'm'),
 
-        Arg::LongOption("syslog", Arg::None),
+        Arg::LongOption("syslog", Arg::NoArg),
         Arg::LongOption("syslog-facility", Arg::Required),
         Arg::LongOption("syslog-priority", Arg::Required),
         Arg::LongOption("syslog-tag", Arg::Required),
 
-        Arg::LongOption("verbose", Arg::None),
+        Arg::LongOption("verbose", Arg::NoArg),
     };
 
     auto longEnd = longOptions + sizeof(longOptions) / sizeof(longOptions[0]);
