@@ -5,8 +5,8 @@
 void Options::usage(std::string const &progname)
 {
     cout << "\n" <<
-    progname << " by " << author << "\n" <<
-    progname << " V" << version << " " << years << "\n"
+    progname << " by " << Icmbuild::author << "\n" <<
+    progname << " V" << Icmbuild::version << " " << Icmbuild::years << "\n"
     "\n"
     "Usage: " << progname << " [options] [crontab]\n"
     "Where:\n"
